@@ -1,11 +1,16 @@
 #!/usr/bin/env python
 
-# Copyright 2012, 2013 Julian Marchant <onpon4@lavabit.com>
+# Multiple Rooms Example
+# Written in 2012, 2013 by Julian Marchant <onpon4@lavabit.com>
 #
-# Copying and distribution of this file, with or without modification,
-# are permitted in any medium without royalty provided the copyright
-# notice and this notice are preserved.  This file is offered as-is,
-# without any warranty.
+# To the extent possible under law, the author(s) have dedicated all
+# copyright and related and neighboring rights to this software to the
+# public domain worldwide. This software is distributed without any
+# warranty.
+#
+# You should have received a copy of the CC0 Public Domain Dedication
+# along with this software. If not, see
+# <http://creativecommons.org/publicdomain/zero/1.0/>.
 
 """Stellar Game Engine example
 
@@ -30,7 +35,7 @@ class glob(object):
 
 
 class Game(sge.Game):
-    def event_key_press(self, key):
+    def event_key_press(self, key, char):
         if key == 'escape':
             self.end()
 
@@ -89,7 +94,7 @@ class Room(sge.Room):
     def event_room_start(self):
         glob.music.play(loops=None)
 
-    def event_key_press(self, key):
+    def event_key_press(self, key, char):
         if key == 'space':
             self.end()
 
@@ -99,11 +104,11 @@ def main():
     game = Game()
 
     # Load sprites
-    circle_sprite = sge.Sprite('circle', 64, 64, 32, 32, True, bbox_x=-32,
-                               bbox_y=-32)
-    circle_pop_sprite = sge.Sprite('circle_pop', 64, 64, 32, 32, True,
-                                   bbox_x=-16, bbox_y=-16, fps=60)
-    fence_sprite = sge.Sprite('fence', transparent=True)
+    circle_sprite = sge.Sprite('circle', width=64, height=64, origin_x=32,
+                               origin_y=32)
+    circle_pop_sprite = sge.Sprite('circle_pop', width=64, height=64,
+                                   origin_x=32, origin_y=32, fps=60)
+    fence_sprite = sge.Sprite('fence')
 
     # Load backgrounds
     layers = (sge.BackgroundLayer(fence_sprite, 0, 380, 0, yrepeat=False),)
