@@ -1,18 +1,24 @@
-# Stellar Game Engine - Pygame 1.9
 # Copyright (C) 2012, 2013 Julian Marchant <onpon4@lavabit.com>
-#
-# This program is free software: you can redistribute it and/or modify
+# 
+# This file is part of SGE Pygame.
+# 
+# SGE Pygame is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
+# 
+# SGE Pygame is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU Lesser General Public License for more details.
-#
+# 
 # You should have received a copy of the GNU Lesser General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with SGE Pygame.  If not, see <http://www.gnu.org/licenses/>.
+
+
+
+
+
 
 import sge
 
@@ -24,24 +30,32 @@ class BackgroundLayer(object):
 
     """Special class used for background layers.
 
-    All BackgroundLayer objects have the following attributes:
-        sprite: The Sprite object used for this layer.  While it will
-            always be an actual Sprite object when read, it can also be
-            set to the ID of a sprite.
-        x: The horizontal offset of the layer.
-        y: The vertical offset of the layer.
-        z: The Z-axis position of the layer in the room, which
-            determines in what order layers are drawn; layers with a
-            higher Z value are drawn in front of layers with a lower Z
-            value.
-        xscroll_rate: The horizontal speed the layer scrolls as a factor
-            of the view scroll speed.
-        yscroll_rate: The vertical speed the layer scrolls as a factor
-            of the view scroll speed.
-        xrepeat: Whether or not the layer should be repeated
-            horizontally.
-        yrepeat: Whether or not the layer should be repeated
-            vertically.
+    This class stores a sprite and certain information for a layer of a
+    background.  In particular, it stores the location of the layer,
+    whether the layer tiles horizontally, vertically, or both, and the
+    rate at which it scrolls.
+
+    Attributes:
+    - ``sprite`` -- The sprite used for this layer.  It will be animated
+      normally if it contains multiple frames.
+    - ``x`` -- The horizontal location of the layer relative to the
+      background.
+    - ``y`` -- The vertical location of the layer relative to the
+      background.
+    - ``z`` -- The Z-axis position of the layer in the room.
+    - ``xscroll_rate`` -- The horizontal rate that the layer scrolls as
+      a factor of the additive inverse of the horizontal movement of the
+      view.
+    - ``yscroll_rate`` -- The vertical rate that the layer scrolls as a
+      factor of the additive inverse of the vertical movement of the
+      view.
+    - ``xrepeat`` -- Whether or not the layer should be repeated (tiled)
+      horizontally.
+    - ``yrepeat`` -- Whether or not the layer should be repeated (tiled)
+      vertically.
+
+    Read-Only Attributes:
+    - ``id`` -- The unique identifier of the layer.
 
     """
 
@@ -128,17 +142,25 @@ class BackgroundLayer(object):
             self._yrepeat = value
             sge.game._background_changed = True
 
-    def __init__(self, sprite, x, y, z, xscroll_rate=1, yscroll_rate=1,
-                 xrepeat=True, yrepeat=True):
+    def __init__(self, sprite, x, y, z, id_=None, xscroll_rate=1,
+                 yscroll_rate=1, xrepeat=True, yrepeat=True, **kwargs):
         """Create a background layer object.
 
-        Arguments set the properties of the layer.  See
-        BackgroundLayer.__doc__ for more information.
+        Arguments:
+        - ``id`` -- The unique identifier of the sprite.  If set to
+          None, the ``id`` attribute of the sprite will be used,
+          modified by SGE if it is already the unique identifier of
+          another background layer.
 
-        A game object must exist before an object of this class is
-        created.
+        All other arguments set the respective initial attributes of the
+        layer.  See the documentation for `BackgroundLayer` for more
+        information.
 
         """
+        # Since the docs say that ``id`` is a valid keyword argument,
+        # you should do this to make sure that that is true.
+        id_ = kwargs.setdefault('id', id_)
+
         self._sprite = sprite
         self._x = x
         self._y = y
@@ -148,6 +170,14 @@ class BackgroundLayer(object):
         self._xrepeat = xrepeat
         self._yrepeat = yrepeat
 
+        if id_ is not None:
+            self.id = id_
+        else:
+            self.id = self.sprite.id
+
+            while self.id in sge.game.background_layers:
+                self.id += "_"
+
         self._image_index = 0
         self._count = 0
         if self.sprite.fps != 0:
@@ -160,6 +190,8 @@ class BackgroundLayer(object):
         else:
             self._frame_time = None
 
+        sge.game.background_layers[self.id] = self
+
     def _update(self, time_passed):
         # Update the animation frame.
         if self._frame_time is not None:
