@@ -1,18 +1,24 @@
-# Stellar Game Engine - Pygame 1.9
 # Copyright (C) 2012, 2013 Julian Marchant <onpon4@lavabit.com>
-#
-# This program is free software: you can redistribute it and/or modify
+# 
+# This file is part of SGE Pygame.
+# 
+# SGE Pygame is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
+# 
+# SGE Pygame is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU Lesser General Public License for more details.
-#
+# 
 # You should have received a copy of the GNU Lesser General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with SGE Pygame.  If not, see <http://www.gnu.org/licenses/>.
+
+
+
+
+
 
 import os
 
@@ -28,34 +34,32 @@ class Music(object):
 
     """Music handling class.
 
-    Music is mostly the same as sound, but only one can be played at a
-    time.
+    This class stores and plays music.  Music is very similar to sound
+    effects, but only one music file can be played at a time, and it is
+    more efficient for larger files than `sge.Sound`.
 
-    All Music objects have the following attributes:
-        volume: The volume of the music in percent (0 for no sound, 100
-            for max sound).
-        balance: The balance of the music on stereo speakers.  A value
-            of 0 means centered (an equal amount of play on both
-            speakers), -1 means entirely in the left speaker, and 1
-            means entirely in the right speaker.  Support for this
-            feature in Stellar Game Engine implementations is optional.
-            If it is unavailable, all music will be played through both
-            speakers equally (assuming stereo sound is used).
+    What music formats are supported depends on the implementation of
+    SGE, but Ogg Vorbis is generally a good choice.  See the
+    implementation-specific information for a full list of supported
+    formats.
 
-    The following read-only attributes are also available:
-        fname: The file name of the music given when it was created.
-            See Music.__init__.__doc__ for more information.
-        length: The length of the music in milliseconds.
-        playing: Whether or not the music is playing.
-        position: The current position (time) on the music in
-            milliseconds.
+    You should avoid the temptation to use MP3 files; MP3 is a patent-
+    encumbered format, so many systems do not support it and royalties
+    to the patent holders may be required for commercial use.  There are
+    many programs which can convert your MP3 files to the free Ogg
+    Vorbis format.
 
-    Music methods:
-        Music.play: Play the music.
-        Music.queue: Queue the music for playback.
-        Music.stop: Stop the music.
-        Music.pause: Pause playback of the music.
-        Music.unpause: Resume playback of the music if paused.
+    Attributes:
+    - ``volume`` -- The volume of the music in percent from 0 to 100 (0
+      for no sound, 100 for maximum volume).
+
+    Read-Only Attributes:
+    - ``fname`` -- The file name of the music given when it was created.
+    - ``id`` -- The unique identifier of the music.
+    - ``length`` -- The length of the music in milliseconds.
+    - ``playing`` -- Whether or not the music is playing.
+    - ``position`` -- The current position (time) playback of the music
+      is at in milliseconds.
 
     """
 
@@ -85,25 +89,28 @@ class Music(object):
         else:
             return 0
 
-    def __init__(self, fname, volume=100, balance=0):
+    def __init__(self, fname, id_=None, volume=100, **kwargs):
         """Create a new music object.
 
-        ``fname`` indicates the name of the sound file, to be located in
-        one of the directories specified in ``music_directories``.  If
-        set to None, this object will not actually play any music
-        (useful as a placeholder, for example).  If ``fname`` is neither
-        a valid sound file nor None, IOError will be raised.
+        Arguments:
+        - ``fname`` -- The name of the sound file in one of the paths
+          specified in ``music_directories``.  If set to None, this
+          object will not actually play any music.  If this is neither a
+          valid sound file nor None, IOError is raised.
+        - ``id`` -- The unique identifier of the music.  If set to None,
+          ``fname`` minus the extension will be used, modified by SGE if
+          it is already the unique idenfifier of another music object.
 
-        All remaining arguments set the initial properties of the music.
-        See Music.__doc__ for more information.
-
-        A game object must exist before an object of this class is
-        created.
+        All other arguments set the respective initial attributes of the
+        music.  See the documentation for `Music` for more information.
 
         """
+        # Since the docs say that ``id`` is a valid keyword argument,
+        # you should do this to make sure that that is true.
+        id_ = kwargs.setdefault('id', id_)
+
         self.fname = fname
         self.volume = volume
-        self.balance = balance
         self._timeout = None
         self._fade_time = None
         self._start = 0
@@ -122,23 +129,36 @@ class Music(object):
                     print(os.path.normpath(os.path.abspath(d)))
                 msg = 'File "{0}" not found.'.format(self.fname)
                 raise IOError(msg)
+
+            if id_ is not None:
+                self.id = id_
+            else:
+                self.id = self.fname
+                while self.id in sge.game.music:
+                    self.id += "_"
         else:
             self._full_fname = None
 
+            if id_ is not None:
+                self.id = id_
+            else:
+                i = 0
+                while i in sge.game.music:
+                    i += 1
+
+                self.id = i
+
+        sge.game.music[self.id] = self
+
     def play(self, start=0, loops=0, maxtime=None, fade_time=None):
         """Play the music.
 
-        If music was already playing when this is called, it will be
-        stopped.
+        Arguments:
 
-        ``start`` indicates the number of milliseconds from the
-        beginning to start at.  ``loops`` indicates the number of extra
-        times to play the sound after it is played the first time; set
-        to -1 or None to loop indefinitely.  ``maxtime`` indicates the
-        maximum amount of time to play the sound in milliseconds; set to
-        0 or None for no limit.  ``fade_time`` indicates the time in
-        milliseconds over which to fade the sound in; set to 0 or None
-        to immediately play the music at full volume.
+        - ``start`` -- The number of milliseconds from the beginning to
+          start playing at.
+
+        See the documentation for `sge.Sound.play` for more information.
 
         """
         if self._full_fname is not None:
@@ -174,44 +194,34 @@ class Music(object):
         This will cause the music to be added to a list of music to play
         in order, after the previous music has finished playing.
 
-        See Music.play.__doc__ for information about the arguments.
+        See the documentation for `Music.play` for more information.
 
         """
         sge.game._music_queue.append((self, start, loops, maxtime, fade_time))
 
-    def stop(self, fade_time=None):
-        """Stop the music.
+    @staticmethod
+    def stop(fade_time=None):
+        """Stop the currently playing music.
 
-        ``fade_time`` indicates the time in milliseconds over which to
-        fade the sound out before stopping; set to 0 or None to
-        immediately stop the music.
+        See the documentation for `sge.Sound.stop` for more information.
 
         """
-        if self.playing:
-            if fade_time:
-                pygame.mixer.music.fadeout(fade_time)
-            else:
-                pygame.mixer.music.stop()
+        if fade_time:
+            pygame.mixer.music.fadeout(fade_time)
+        else:
+            pygame.mixer.music.stop()
 
-    def pause(self):
-        """Pause playback of the music."""
-        if self.playing:
-            pygame.mixer.music.pause()
+    @staticmethod
+    def pause():
+        """Pause playback of the currently playing music."""
+        pygame.mixer.music.pause()
 
-    def unpause(self):
-        """Resume playback of the music if paused."""
-        if self.playing:
-            pygame.mixer.music.unpause()
+    @staticmethod
+    def unpause():
+        """Resume playback of the currently playing music if paused."""
+        pygame.mixer.music.unpause()
 
     @staticmethod
     def clear_queue():
         """Clear the music queue."""
         sge.game._music_queue = []
-
-    @staticmethod
-    def stop_all():
-        """Stop playback of any music and clear the queue."""
-        for i in sge.game.music:
-            sge.game.music[i].stop()
-
-        Music.clear_queue()
