@@ -1,18 +1,24 @@
-# Stellar Game Engine - Pygame 1.9
 # Copyright (C) 2012, 2013 Julian Marchant <onpon4@lavabit.com>
-#
-# This program is free software: you can redistribute it and/or modify
+# 
+# This file is part of SGE Pygame.
+# 
+# SGE Pygame is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
+# 
+# SGE Pygame is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU Lesser General Public License for more details.
-#
+# 
 # You should have received a copy of the GNU Lesser General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with SGE Pygame.  If not, see <http://www.gnu.org/licenses/>.
+
+
+
+
+
 
 import os
 
@@ -28,30 +34,27 @@ class Sound(object):
 
     """Sound handling class.
 
-    All Sound objects have the following attributes:
-        volume: The volume of the sound in percent (0 for no sound, 100
-            for max sound).
-        balance: The balance of the sound effect on stereo speakers.  A
-            value of 0 means centered (an equal amount of play on both
-            speakers), -1 means entirely in the left speaker, and 1
-            means entirely in the right speaker.  Support for this
-            feature in Stellar Game Engine implementations is optional.
-            If it is unavailable, all sounds will be played through both
-            speakers equally (assuming stereo sound is used).
-        max_play: The maximum instances of this sound playing permitted.
-            Set to 0 for no limit.
+    This class stores and plays sound effects.  Note that this is
+    inefficient for large music files; for those, use sge.Music instead.
 
-    The following read-only attributes are also available:
-        fname: The file name of the sound given when it was created.
-            See Sound.__init__.__doc__ for more information.
-        length: The length of the sound in milliseconds.
-        playing: The number of instances of this sound playing.
+    What sound formats are supported depends on the implementation of
+    SGE, but sound formats that are generally a good choice are Ogg
+    Vorbis and uncompressed WAV.  See the implementation-specific
+    information for a full list of supported formats.
 
-    Sound methods:
-        Sound.play: Play the sound.
-        Sound.stop: Stop the sound.
-        Sound.pause: Pause playback of the sound.
-        Sound.unpause: Resume playback of the sound if paused.
+    Attributes:
+    - ``volume`` -- The volume of the sound in percent from 0 to 100 (0
+      for no sound, 100 for max sound).
+    - ``max_play`` -- The maximum number of instances of this sound
+      playing permitted.  If a sound is played while this number of the
+      instances of the same sound are already playing, one of the
+      already playing sounds will be stopped before playing the new
+      instance.  Set to None or 0 for no limit.
+
+    Read-Only Attributes:
+    - ``fname`` -- The file name of the sound given when it was created.
+    - ``length`` -- The length of the sound in milliseconds.
+    - ``playing`` -- The number of instances of this sound playing.
 
     """
 
@@ -61,6 +64,9 @@ class Sound(object):
 
     @max_play.setter
     def max_play(self, value):
+        if value is None:
+            value = 0
+
         if self._sound is not None:
             value = max(0, value)
             while len(self._channels) < value:
@@ -82,22 +88,26 @@ class Sound(object):
         else:
             return 0
 
-    def __init__(self, fname, volume=100, balance=0, max_play=1):
+    def __init__(self, fname, id_=None, volume=100, max_play=1, **kwargs):
         """Create a new sound object.
 
-        ``fname`` indicates the name of the sound file, to be located in
-        one of the directories specified in ``sound_directories``.  If
-        set to None, this object will not actually play any sound
-        (useful as a placeholder, for example).  If ``fname`` is neither
-        a valid sound file nor None, IOError will be raised.
+        Arguments:
+        - ``fname`` -- The name of the sound file in one of the paths
+          specified in ``sound_directories``.  If set to None, this
+          object will not actually play any sound.  If this is neither a
+          valid sound file nor None, IOError is raised.
+        - ``id`` -- The unique identifier of the sound.  If set to None,
+          ``fname`` minus the extension will be used, modified by SGE if
+          it is already the unique identifier of another music object.
 
-        All remaining arguments set the initial properties of the sound.
-        See Sound.__doc__ for more information.
-
-        A game object must exist before an object of this class is
-        created.
+        All other arguments set the respective initial attributes of the
+        sound.  See the documentation for `Sound` for more information.
 
         """
+        # Since the docs say that ``id`` is a valid keyword argument,
+        # you should do this to make sure that that is true.
+        id_ = kwargs.setdefault('id', id_)
+
         if fname is not None and pygame.mixer.get_init():
             self._sound = None
             for path in sge.sound_directories:
@@ -121,19 +131,28 @@ class Sound(object):
         self._temp_channels = []
         self.fname = fname
         self.volume = volume
-        self.balance = balance
         self.max_play = max_play
 
-    def play(self, loops=0, maxtime=None, fade_time=None):
+    def play(self, loops=0, volume=100, balance=0, maxtime=None,
+             fade_time=None):
         """Play the sound.
 
-        ``loops`` indicates the number of extra times to play the sound
-        after it is played the first time; set to -1 or None to loop
-        indefinitely.  ``maxtime`` indicates the maximum amount of time
-        to play the sound in milliseconds; set to 0 or None for no
-        limit. ``fade_time`` indicates the time in milliseconds over
-        which to fade the sound in; set to 0 or None to immediately play
-        the sound at full volume.
+        Arguments:
+        - ``loops`` -- The number of extra times to play the sound after
+          it is played the first time; set to None or -1 to loop
+          indefinitely.
+        - ``volume`` -- The volume to play the sound at as a percentage
+          of ``self.volume`` from 0 to 100 (0 for no sound, 100 for
+          ``self.volume``).
+        - ``balance`` -- The balance of the sound effect on stereo
+          speakers as a float from -1 to 1, where 0 is centered (full
+          volume in both speakers), 1 is entirely in the right speaker,
+          and -1 is entirely in the left speaker.
+        - ``maxtime`` -- The maximum amount of time to play the sound in
+          milliseconds; set to None or 0 for no limit.
+        - ``fade_time`` -- The time in milliseconds over which to fade
+          the sound in; set to None or 0 to immediately play the sound
+          at full volume.
 
         """
         if self._sound is not None:
@@ -144,17 +163,28 @@ class Sound(object):
             if fade_time is None:
                 fade_time = 0
 
+            # Calculate volume for each speaker
+            left_volume = volume / 100
+            right_volume = left_volume
+            if balance < 0:
+                right_volume *= 1 - abs(balance)
+            elif balance > 0:
+                left_volume *= 1 - abs(balance)
+
             if self.max_play:
                 for channel in self._channels:
                     if not channel.get_busy():
                         channel.play(self._sound, loops, maxtime, fade_time)
+                        channel.set_volume(left_volume, right_volume)
                         break
                 else:
                     self._channels[0].play(self._sound, loops, maxtime,
                                            fade_time)
+                    self._channels[0].set_volume(left_volume, right_volume)
             else:
                 channel = sge.game._get_channel()
                 channel.play(self._sound, loops, maxtime, fade_time)
+                channel.set_volume(left_volume, right_volume)
                 self._temp_channels.append(channel)
 
             # Clean up old temporary channels
@@ -165,9 +195,10 @@ class Sound(object):
     def stop(self, fade_time=None):
         """Stop the sound.
 
-        ``fade_time`` indicates the time in milliseconds over which to
-        fade the sound out before stopping; set to 0 or None to
-        immediately stop the sound.
+        Arguments:
+        - ``fade_time`` -- The time in milliseconds over which to fade
+          the sound out before stopping; set to None or 0 to immediately
+          stop the sound.
 
         """
         if self._sound is not None:
