@@ -1,18 +1,19 @@
-# Stellar Game Engine - Pygame 1.9
 # Copyright (C) 2012, 2013 Julian Marchant <onpon4@lavabit.com>
-#
-# This program is free software: you can redistribute it and/or modify
+# 
+# This file is part of SGE Pygame.
+# 
+# SGE Pygame is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
+# 
+# SGE Pygame is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU Lesser General Public License for more details.
-#
+# 
 # You should have received a copy of the GNU Lesser General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with SGE Pygame.  If not, see <http://www.gnu.org/licenses/>.
 
 from __future__ import division
 from __future__ import absolute_import
@@ -31,35 +32,31 @@ class Background(object):
 
     """Background class.
 
-    All Background objects have the following attributes:
-        x: The horizontal position of the background in the room.
-        y: The vertical position of the background in the room.
-        color: A Stellar Game Engine color used in parts of the
-            background where there is no layer.
+    This class stores the layers that make up the background (which
+    contain the information about what images to use and where) as well as
+    the color to use where no image is shown.
 
-    The following read-only attributes are also available:
-        id: The unique identifier for this background.
-        layers: A tuple containing all BackgroundLayer objects used in
-            this background.
+    Attributes:
+    - ``color`` -- The color used in parts of the background where no
+      layer is shown.
+
+    Read-Only Attributes:
+    - ``id`` -- The unique identifier for this background.
+    - ``layers`` -- A tuple containing all `sge.BackgroundLayer` objects
+      used in this background.
 
     """
 
-    def __init__(self, layers, color, x=0, y=0, id_=None, **kwargs):
+    def __init__(self, layers, color, id_=None, **kwargs):
         """Create a background with the given color and layers.
 
-        Arguments set the properties of the background.  See
-        Background.__doc__ for more information.
+        Arguments:
+        - ``id`` -- The unique identifier of the sprite.  If set to
+          None, SGE chooses the value.
 
-        If ``id`` is None, it will be set to an integer not currently
-        used as an ID (the exact number chosen is implementation-
-        specific and may not necessarily be the same between runs).
-
-        In addition to containing actual BackgroundLayer objects,
-        ``layers`` can contain valid names of BackgroundLayer objects'
-        sprites.
-
-        A game object must exist before an object of this class is
-        created.
+        All other arguments set the respective initial attributes of the
+        background.  See the documentation for `Background` for more
+        information.
 
         """
         # Since the docs say that ``id`` is a valid keyword argument,
@@ -67,8 +64,6 @@ class Background(object):
         id_ = kwargs.setdefault('id', id_)
 
         self.color = color
-        self.x = x
-        self.y = y
 
         if id_ is not None:
             self.id = id_
@@ -121,10 +116,12 @@ class Background(object):
             for layer in self.layers:
                 image = layer._get_image()
                 x = int(round(
-                    (self.x + layer.x - (view.x * layer.xscroll_rate)) *
+                    (sge.game.current_room.background_x + layer.x -
+                     (view.x * layer.xscroll_rate)) *
                     sge.game._xscale))
                 y = int(round(
-                    (self.y + layer.y - (view.y * layer.yscroll_rate)) *
+                    (sge.game.current_room.background_y + layer.y -
+                     (view.y * layer.yscroll_rate)) *
                     sge.game._yscale))
                 image_w = max(1, image.get_width())
                 image_h = max(1, image.get_height())
@@ -139,8 +136,8 @@ class Background(object):
                     y = (y % image_h) - image_h
 
                 # Apply the origin so the positions are as expected.
-                x -= layer.sprite.origin_x
-                y -= layer.sprite.origin_y
+                x -= int(round(layer.sprite.origin_x * sge.game._xscale))
+                y -= int(round(layer.sprite.origin_y * sge.game._yscale))
 
                 if layer.xrepeat and layer.yrepeat:
                     xstart = x
